@@ -409,7 +409,6 @@ setMethod(f='show', signature='PushoverMessage',
 #' @param object A \code{\link{PushoverMessage-class}} object
 #' @return A \code{\link{PushoverResponse}} object containing information about
 #' the server's response.
-#' @importFrom httr POST
 #' 
 send_pushovermessage <- function(object)
 {
@@ -428,7 +427,7 @@ send_pushovermessage <- function(object)
     if(!is.na(object@timestamp)) params['timestamp'] <- object@timestamp
     if(!is.na(object@callback)) params['callback'] <- object@callback
     
-    response <- POST(url="https://api.pushover.net:443/1/messages.json",
+    response <- POST(url="https://api.pushover.net/1/messages.json",
                      body=params)
     
     attr(response$headers, 'class') <- 'list'
